@@ -1,10 +1,12 @@
 ##############################################################################
 ##
 ##  Web::Reactor application machinery
-##  2013-2016 (c) Vladi Belperchinov-Shabanski "Cade"
-##  <cade@bis.bg> <cade@biscom.net> <cade@cpan.org>
-##
+##  Copyright (c) 2013-2022 Vladi Belperchinov-Shabanski "Cade"
+##        <cade@noxrun.com> <cade@bis.bg> <cade@cpan.org>
+##  http://cade.noxrun.com
+##  
 ##  LICENSE: GPLv2
+##  https://github.com/cade-vs/perl-web-reactor
 ##
 ##############################################################################
 package Web::Reactor::Preprocessor;
@@ -12,27 +14,6 @@ use strict;
 
 use parent 'Web::Reactor::Base'; 
  
-sub new
-{
-  my $class = shift;
-  my %env = @_;
-  
-  $class = ref( $class ) || $class;
-  my $self = {
-             'ENV'       => \%env,
-             };
-  bless $self, $class;
-  # rcd_log( "debug: rcd_rec:$self created" );
-  
-  return $self;
-}
-
-sub load_file
-{
-  my $self = shift;
-
-}
-
 # constructs real filesystem/storage file name and load the page_text
 # args:
 #       $page_name  -- page name, it should be sanitized and load from file,
