@@ -1,32 +1,21 @@
 ##############################################################################
 ##
 ##  Web::Reactor application machinery
-##  2013-2016 (c) Vladi Belperchinov-Shabanski "Cade"
-##  <cade@bis.bg> <cade@biscom.net> <cade@cpan.org>
-##
+##  Copyright (c) 2013-2022 Vladi Belperchinov-Shabanski "Cade"
+##        <cade@noxrun.com> <cade@bis.bg> <cade@cpan.org>
+##  http://cade.noxrun.com
+##  
 ##  LICENSE: GPLv2
+##  https://github.com/cade-vs/perl-web-reactor
 ##
 ##############################################################################
 package Web::Reactor::Sessions;
 use strict;
 use Exception::Sink;
+use Data::Tools 1.24;
 
 use parent 'Web::Reactor::Base'; 
 
-sub new
-{
-  my $class = shift;
-  my %env = @_;
- 
-  $class = ref( $class ) || $class;
-  my $self = {
-             'ENV'       => \%env,
-             };
-  bless $self, $class;
- 
-  return $self;
-}
-
 ##############################################################################
 ##
 ##  public interface methods, should be used via Reactor object, see specs
@@ -42,16 +31,16 @@ sub create
 {
   my $self = shift;
   my $type = uc shift;
-  my $len  = shift || 128;
+  my $len  = shift || 97;
 
   die "Web::Reactor::Sessions::create: invalid type, expected ALPHANUMERIC, got [$type]" unless $type =~ /^[A-Z0-9]+$/;
   die "Web::Reactor::Sessions::create: invalid length, expected len > 0, got [$len]" unless $len > 0;
 
-  my $env  = $self->_renv();
+  my $cfg  = $self->get_cfg();
 
   my $id;
   my $t  = time();
-  my $to = $env->{ 'SESS_CREATE_TIMEOUT' } || 5; # seconds
+  my $to = $cfg->{ 'SESS_CREATE_TIMEOUT' } || 5; # seconds
   while(4)
     {
     $id = $self->create_id( $len );
@@ -207,16 +196,12 @@ sub _storage_exists { die "Web::Reactor::Sessions::*::_storage_exists() is not i
 sub create_id
 {
   my $self = shift;
-  my $env  = $self->_renv();
+  my $cfg  = $self->get_cfg();
  
-  my $len = shift() || $env->{ 'SESS_LENGTH'  } || 128;
-  my $let = shift() || $env->{ 'SESS_LETTERS' } || 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
+  my $len = shift() || $cfg->{ 'SESS_LENGTH'  } || 128;
+  my $let = shift() || $cfg->{ 'SESS_LETTERS' } || 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
 
-  my $l = length( $let );
-  my $id;
-  # FIXME: move this line to function in Utils.pm
-  $id .= substr( $let, int(rand() * $l), 1 ) for ( 1 .. $len );
-  return $id;
+  return create_random_id( $len, $let );
 };
 
 sub compose_key_from_id
@@ -251,15 +236,6 @@ sub get_user_sid
   return $user_sid;
 }
 
-# return ENV hash reference from the reactor
-# FIXME: TODO: move to Web::Reactor::Base::get_env()
-sub _renv
-{
-  my $self = shift;
-  
-  $self->get_reo()->{ 'ENV' };
-}
-
 #sub DESTROY
 #{
 #  my $self = shift;
